@@ -150,6 +150,26 @@ class SmokeTest {
 		System.Console.WriteLine("MatchDecider mset has wrong docid in");
 		System.Environment.Exit(1);
 	    }
+
+
+            // Test setting and getting metadata
+            if (db.GetMetadata("Foo") !=  "") {
+		System.Console.WriteLine("db.GetMetadata(\"Foo\") returned wrong value \"" + db.GetMetadata("Foo") + "\" - expected \"\"");
+		System.Environment.Exit(1);
+            }
+            db.SetMetadata("Foo", "Foo");
+            if (db.GetMetadata("Foo") !=  "Foo") {
+		System.Console.WriteLine("db.GetMetadata(\"Foo\") returned wrong value \"" + db.GetMetadata("Foo") + "\" - expected \"Foo\"");
+		System.Environment.Exit(1);
+            }
+
+	    // Test OP_SCALE_WEIGHT and corresponding constructor
+	    Xapian.Query query4 = new Xapian.Query(Xapian.Query.op.OP_SCALE_WEIGHT, new Xapian.Query("foo"), 5.0);
+	    if (query4.GetDescription() != "Xapian::Query(5 * foo)") {
+		System.Console.WriteLine("Unexpected query4.GetDescription()");
+		System.Environment.Exit(1);
+	    }
+
 	} catch (System.Exception e) {
 	    System.Console.WriteLine("Exception: " + e.ToString());
 	    System.Environment.Exit(1);
