@@ -28,15 +28,16 @@ if ($v != $v2) {
 }
 
 $db = Xapian::inmemory_open();
+$db2 = Xapian::inmemory_open();
 
 # Check PHP5 handling of Xapian::DocNotFoundError
 try {
-    $doc2 = Database_get_document($db, 2);
+    $doc2 = $db->get_document(2);
     print "Retrieved non-existent document\n";
     exit(1);
 } catch (Exception $e) {
     if ($e->getMessage() !== "DocNotFoundError: Docid 2 not found") {
-	print "DocNotFoundError Exception string not as expected, got: '$e->getMessage()'\n";
+	print "DocNotFoundError Exception string not as expected, got: '{$e->getMessage()}'\n";
 	exit(1);
     }
 }
@@ -54,9 +55,24 @@ try {
     }
 }
 
+# Regression test for bug#193, fixed in 1.0.3.
+$vrp = new XapianNumberValueRangeProcessor(0, '$', true);
+$a = '$10';
+$b = '20';
+$vrp->apply($a, $b);
+if (Xapian::sortable_unserialise($a) != 10) {
+    print Xapian::sortable_unserialise($a)." != 10\n";
+    exit(1);
+}
+if (Xapian::sortable_unserialise($b) != 20) {
+    print Xapian::sortable_unserialise($b)." != 20\n";
+    exit(1);
+}
+
 $op_or = XapianQuery::OP_OR;
 $op_phrase = XapianQuery::OP_PHRASE;
 $op_xor = XapianQuery::OP_XOR;
 $op_elite_set = XapianQuery::OP_ELITE_SET;
+$op_scale_weight = XapianQuery::OP_SCALE_WEIGHT;
 
 ?>
