@@ -180,4 +180,16 @@ class XapianSmoketest < Test::Unit::TestCase
     assert_equal(mset.docid(0), 2)
   end
 
+  def test_012_metadata
+    assert_equal(@db.get_metadata('Foo'), '')
+    @db.set_metadata('Foo', 'Foo')
+    assert_equal(@db.get_metadata('Foo'), 'Foo')
+  end
+
+  def test_013_scaleweight
+    query = Xapian::Query.new("foo")
+    query2 = Xapian::Query.new(Xapian::Query::OP_SCALE_WEIGHT, query, 5);
+    assert_equal(query2.description(), "Xapian::Query(5 * foo)")
+  end
+
 end # class XapianSmoketest
